import {
  csv,
  text,
  tsv,
  select,
  forceSimulation,
  forceLink,
  forceManyBody,
  forceCenter
} from 'd3';

const svg1 = d3.select('#svg1');
const svg2 = d3.select('#svg2');
      

function node_link(node,link){
	//console.log(node);
  //console.log(link);
  var text = svg1.append("text")
  .attr('x',-300).attr('y',0)
  .attr('stroke',"#f00")
  .text("Drag to move graph")
  .attr('font-size',"3.3em");
  var text1 = svg1.append("text")
  .attr('x',-300).attr('y',40)
  .attr('stroke',"#f00")
  .text("Mouse scroll up nad down to resize graph")
  .attr('font-size',"3.3em");
  var links = svg1
    .attr('stroke', '#ADADAD')
    .selectAll('line')
    .data(link)
    .join('line')
    .attr('stroke-width', 1);

	var nodes = svg1
    .append('g')
    .attr('stroke', '#5B5B5B')
    .attr('stroke-width', 2)
    .selectAll('circle')
    .data(node)
    .join('circle')
    .attr('r', 5)
    .attr('fill', (d) => d3.schemeCategory10[d.group]);

	var simulation = d3.forceSimulation(node)
    .force(
      "links",
      d3.forceLink().id(function(d){return d.id;}).links(link)
    )
    .force('charge', d3.forceManyBody())
    .force('center', d3.forceCenter(480 / 2, 960 / 2))
  	.on("tick", ticked);

  function ticked() {
    links
      .attr('x1', (d) => d.source.x)
      .attr('y1', (d) => d.source.y)
      .attr('x2', (d) => d.target.x)
      .attr('y2', (d) => d.target.y);

    nodes
      .attr('cx', (d) => d.x)
      .attr('cy', (d) => d.y);
  }
  svg1.attr('viewBox', [-500, -10, 1500, 1100]);
	var x,y,s;

	var zoom = d3.zoom()
  	.extent([[0, 0],[450, 600],])
    .scaleExtent([1, 10])
    .on("zoom", zoomed);

	function zoomed({ transform }) {
		s=transform.k;
    x=transform.x;
    y=transform.y;
  	links.attr('transform', transform);
  	nodes.attr('transform', transform);
	}
	svg1.call(zoom);

  /*d3.selectAll('circle').on('click',function(){
    var circle = d3.select(this);
    circle.transition().duration(250).tween("zoom", function() {
      var r = this.getAttribute('r')*1;
      var cx = this.getAttribute('cx')*1;
      var cy = this.getAttribute('cy')*1;
      var si = d3.interpolate(s, 4);
   		var xi = d3.interpolate(x, (480-r)/2-4*cx);
    	var yi = d3.interpolate(y, (960-r)/2-4*cy);
      return function(t){
      	 svg1.call(zoom.translate([xi(t),yi(t)]).scale(si(t)).event);
    	}
    });
  });*/

  nodes.append('title').text((d) => d.id);
};
function matrix(node,link){
		
	var edgeHash = {};
	link.forEach((e) =>{
		var id = e.source.id + "-" + e.target.id;
		edgeHash[id] = e;
    id = e.target.id + "-" + e.source.id;
    edgeHash[id] = e;		
	});

	var matrix = [];
	node.forEach((source, a) => {
    node.forEach((target, b) => {
      var grid = {id: source.id + "-" + target.id, x: b, y: a, weight: 0};
      if(edgeHash[grid.id]){
         grid.weight = 1;
       }
      matrix.push(grid);
    });
	});
  console.log(matrix);
  svg2
		.attr("transform", "translate("+610+","+-600+")");
	var text1 = svg2.append("text")
  	.attr('x',0).attr('y',15)
  	.attr('stroke',"#f00")
  	.text("You can put your mouth on one of the matrix element,and check the highlighted row and column")
  	.attr('font-size',"1em");
	svg2
    .append("g")
		.attr("transform","translate(47.5,50)")
		.attr("id","adjacencyG")
		.selectAll("rect")
		.data(matrix)
		.enter()
		.append("rect")
		.attr("class","grid")
		.attr("width",20)
		.attr("height",20)
		.attr("x", d=> d.x*20)
		.attr("y", d=> d.y*20)
		.style("fill-opacity", d=> d.weight)
		.style('stroke-width', '1px')
    .style('stroke', '#999');
	svg2
		.append("g")
		.attr("transform","translate(52,49)")
		.selectAll("text")
		.data(node)
		.enter()
		.append("text")
		.attr("x", (d,i) => i*20+5)
		.text(d => d.id)
		.style("text-anchor","middle")
		.style("font-size","10px");
		
	svg2
		.append("g").attr("transform","translate(45,58)")
		.selectAll("text")
		.data(node)
		.enter()
		.append("text")
		.attr("y",(d,i) => i*20+5)
		.text(d => d.id)
		.style("text-anchor","end")
		.style("font-size","10px");

	
	d3.selectAll("rect.grid").on("click", gridOver); 
	
	function gridOver(d) {
		d3.selectAll("rect").style("stroke-width", function(p) { return p.x == d.x || p.y == d.y ? "3px" : "1px"});
	};
}
d3.csv('data.csv').then((data) => {
	var node = [];
  var link = [];
  var link_q = [];
  var key = Object.keys(data[0])[0];
  link.push({
    source: key.split(' ')[0],
    target: key.split(' ')[1],
  });
  for(var i=1;i<1000;i++)
    link_q[i]=0;
   data.forEach(d => {
					key=Object.keys(d);
     			var tmp=d[key].split(' ');
     
     			link.push({
              source: tmp[0],
            	target: tmp[1],
          });
     			
     			link_q[tmp[0]]++;
     			link_q[tmp[1]]++;
       });
  	for( var i=1;i<1000;i++)
      if(link_q[i]!=0)
        node.push({
          id: String(i), 
          group: Math.ceil(link_q[i]/10),
        });
	//console.log(node);
  node_link(node,link);
  matrix(node,link);
});